@@ -7,9 +7,17 @@ from typing import Any, Dict, Generic, List, Optional, Sequence, TypeVar
 from opentelemetry.sdk.trace import ReadableSpan
 from opentelemetry.sdk.trace.export import SpanExporter, SpanExportResult
 
+from ..._events._event_bus import EventBus
+from ..._events._events import (
+    EvalRunCreatedEvent,
+    EvalRunUpdatedEvent,
+    EvalSetRunCreatedEvent,
+    EvalSetRunUpdatedEvent,
+    EvaluationEvents,
+)
 from ...eval.evaluators import BaseEvaluator
 from ...eval.models import EvaluationResult
-from ...eval.models.models import AgentExecution
+from ...eval.models.models import AgentExecution, EvalItemResult
 from .._runtime._contracts import (
     UiPathBaseRuntime,
     UiPathRuntimeContext,
@@ -75,10 +83,16 @@ class UiPathEvalContext(UiPathRuntimeContext):
 class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
     """Specialized runtime for evaluation runs, with access to the factory."""
 
-    def __init__(self, context: UiPathEvalContext, factory: UiPathRuntimeFactory[T, C]):
+    def __init__(
+        self,
+        context: UiPathEvalContext,
+        factory: UiPathRuntimeFactory[T, C],
+        event_bus: EventBus,
+    ):
         super().__init__(context)
         self.context: UiPathEvalContext = context
         self.factory: UiPathRuntimeFactory[T, C] = factory
+        self.event_bus: EventBus = event_bus
         self.span_exporter: ExecutionSpanExporter = ExecutionSpanExporter()
         self.factory.add_span_exporter(self.span_exporter)
 
@@ -87,50 +101,119 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
         cls,
         context: UiPathEvalContext,
         factory: UiPathRuntimeFactory[T, C],
+        event_bus: EventBus,
     ) -> "UiPathEvalRuntime[T, C]":
-        return cls(context, factory)
+        return cls(context, factory, event_bus)
 
     async def execute(self) -> Optional[UiPathRuntimeResult]:
-        """Evaluation logic. Can spawn other runtimes through the factory."""
         if self.context.eval_set is None:
             raise ValueError("eval_set must be provided for evaluation runs")
 
+        if not self.context.execution_id:
+            raise ValueError("execution_id must be provided for evaluation runs")
+
+        event_bus = self.event_bus
+
         evaluation_set = EvalHelpers.load_eval_set(
             self.context.eval_set, self.context.eval_ids
         )
         evaluators = self._load_evaluators(evaluation_set)
+
+        evaluator_averages = {evaluator.id: 0.0 for evaluator in evaluators}
+        evaluator_counts = {evaluator.id: 0 for evaluator in evaluators}
+
+        await event_bus.publish(
+            EvaluationEvents.CREATE_EVAL_SET_RUN,
+            EvalSetRunCreatedEvent(
+                execution_id=self.context.execution_id,
+                entrypoint=self.context.entrypoint or "",
+                eval_set_id=evaluation_set.id,
+                no_of_evals=len(evaluation_set.evaluations),
+                evaluators=evaluators,
+            ),
+        )
+
         results = UiPathEvalOutput(
             evaluation_set_name=evaluation_set.name, score=0, evaluation_set_results=[]
         )
         for eval_item in evaluation_set.evaluations:
+            await event_bus.publish(
+                EvaluationEvents.CREATE_EVAL_RUN,
+                EvalRunCreatedEvent(
+                    execution_id=self.context.execution_id,
+                    eval_item=eval_item,
+                ),
+            )
+
             evaluation_run_results = EvaluationRunResult(
                 evaluation_name=eval_item.name, evaluation_run_results=[]
             )
 
             results.evaluation_set_results.append(evaluation_run_results)
+
             agent_execution_output = await self.execute_runtime(eval_item)
-            # we run each evaluator on the agent_output
+            evaluation_item_results: list[EvalItemResult] = []
+
             for evaluator in evaluators:
                 evaluation_result = await self.run_evaluator(
                     evaluator=evaluator,
                     execution_output=agent_execution_output,
                     eval_item=eval_item,
                 )
+
+                dto_result = EvaluationResultDto.from_evaluation_result(
+                    evaluation_result
+                )
+                evaluator_counts[evaluator.id] += 1
+                count = evaluator_counts[evaluator.id]
+                evaluator_averages[evaluator.id] += (
+                    dto_result.score - evaluator_averages[evaluator.id]
+                ) / count
+
                 evaluation_run_results.evaluation_run_results.append(
                     EvaluationRunResultDto(
                         evaluator_name=evaluator.name,
-                        result=EvaluationResultDto.from_evaluation_result(
-                            evaluation_result
-                        ),
+                        result=dto_result,
+                    )
+                )
+                evaluation_item_results.append(
+                    EvalItemResult(
+                        evaluator_id=evaluator.id,
+                        result=evaluation_result,
                     )
                 )
 
+            evaluation_run_results.compute_average_score()
+
+            await event_bus.publish(
+                EvaluationEvents.UPDATE_EVAL_RUN,
+                EvalRunUpdatedEvent(
+                    execution_id=self.context.execution_id,
+                    eval_item=eval_item,
+                    eval_results=evaluation_item_results,
+                    success=not agent_execution_output.result.error,
+                    agent_output=agent_execution_output.result.output,
+                    agent_execution_time=agent_execution_output.execution_time,
+                    spans=agent_execution_output.spans,
+                ),
+                wait_for_completion=False,
+            )
+
         results.compute_average_score()
+
+        await event_bus.publish(
+            EvaluationEvents.UPDATE_EVAL_SET_RUN,
+            EvalSetRunUpdatedEvent(
+                execution_id=self.context.execution_id,
+                evaluator_scores=evaluator_averages,
+            ),
+            wait_for_completion=False,
+        )
+
         self.context.result = UiPathRuntimeResult(
             output={**results.model_dump(by_alias=True)},
             status=UiPathRuntimeStatus.SUCCESSFUL,
         )
-
         return self.context.result
 
     async def execute_runtime(
@@ -141,11 +224,21 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
             input_json=eval_item.inputs,
             is_eval_run=True,
         )
+        attributes = {
+            "evalId": eval_item.id,
+            "span_type": "eval",
+        }
+        if runtime_context.execution_id:
+            attributes["execution.id"] = runtime_context.execution_id
+
         start_time = time()
+
         result = await self.factory.execute_in_root_span(
-            runtime_context, root_span=eval_item.name
+            runtime_context, root_span=eval_item.name, attributes=attributes
         )
+
         end_time = time()
+
         if runtime_context.execution_id is None:
             raise ValueError("execution_id must be set for eval runs")
 
